@@ -207,6 +207,16 @@ func Init() error {
 	viper.SetDefault("a-general.page_max_time", 10)
 	viper.SetDefault("a-general.scrollbar", "auto")
 	viper.SetDefault("a-general.underline", true)
+	viper.SetDefault("commands.command1", "")
+	viper.SetDefault("commands.command2", "")
+	viper.SetDefault("commands.command3", "")
+	viper.SetDefault("commands.command4", "")
+	viper.SetDefault("commands.command5", "")
+	viper.SetDefault("commands.command6", "")
+	viper.SetDefault("commands.command7", "")
+	viper.SetDefault("commands.command8", "")
+	viper.SetDefault("commands.command9", "")
+	viper.SetDefault("commands.command0", "")
 	viper.SetDefault("keybindings.bind_reload", []string{"R", "Ctrl-R"})
 	viper.SetDefault("keybindings.bind_home", "Backspace")
 	viper.SetDefault("keybindings.bind_bookmarks", "Ctrl-B")
@@ -250,10 +260,33 @@ func Init() error {
 	viper.SetDefault("keybindings.bind_tab8", "*")
 	viper.SetDefault("keybindings.bind_tab9", "(")
 	viper.SetDefault("keybindings.bind_tab0", ")")
+	viper.SetDefault("keybindings.bind_command1", "Alt-!")
+	viper.SetDefault("keybindings.bind_command2", "Alt-@")
+	viper.SetDefault("keybindings.bind_command3", "Alt-#")
+	viper.SetDefault("keybindings.bind_command4", "Alt-$")
+	viper.SetDefault("keybindings.bind_command5", "Alt-%")
+	viper.SetDefault("keybindings.bind_command6", "Alt-^")
+	viper.SetDefault("keybindings.bind_command7", "Alt-&")
+	viper.SetDefault("keybindings.bind_command8", "Alt-*")
+	viper.SetDefault("keybindings.bind_command9", "Alt-(")
+	viper.SetDefault("keybindings.bind_command0", "Alt-)")
+	viper.SetDefault("keybindings.bind_command_target1", "Alt-1")
+	viper.SetDefault("keybindings.bind_command_target2", "Alt-2")
+	viper.SetDefault("keybindings.bind_command_target3", "Alt-3")
+	viper.SetDefault("keybindings.bind_command_target4", "Alt-4")
+	viper.SetDefault("keybindings.bind_command_target5", "Alt-5")
+	viper.SetDefault("keybindings.bind_command_target6", "Alt-6")
+	viper.SetDefault("keybindings.bind_command_target7", "Alt-7")
+	viper.SetDefault("keybindings.bind_command_target8", "Alt-8")
+	viper.SetDefault("keybindings.bind_command_target9", "Alt-9")
+	viper.SetDefault("keybindings.bind_command_target0", "Alt-0")
 	viper.SetDefault("keybindings.bind_copy_page_url", "C")
 	viper.SetDefault("keybindings.bind_copy_target_url", "c")
 	viper.SetDefault("keybindings.bind_beginning", []string{"Home", "g"})
 	viper.SetDefault("keybindings.bind_end", []string{"End", "G"})
+	viper.SetDefault("keybindings.bind_search", "/")
+	viper.SetDefault("keybindings.bind_next_match", "n")
+	viper.SetDefault("keybindings.bind_prev_match", "N")
 	viper.SetDefault("keybindings.shift_numbers", "")
 	viper.SetDefault("keybindings.bind_url_handler_open", "Ctrl-U")
 	viper.SetDefault("url-handlers.other", "default")
