@@ -49,6 +49,13 @@ var helpCells = strings.TrimSpace(
 		"%s\tSave the current page to your downloads.\n" +
 		"%s\tView subscriptions\n" +
 		"%s\tAdd or update a subscription\n" +
+		"%s\tExecute a custom command using the current page URL as an argument.\n" +
+		"\t(Default: Alt-Shift-NUMBER)\n" +
+		"%s\tExecute a custom command using the selected URL as an argument.\n" +
+		"\t(Default: Alt-NUMBER)\n" +
+		"%s\tSearch the page content for a string\n" +
+		"%s\tFind next search match\n" +
+		"%s\tFind previous search match\n" +
 		"%s\tQuit\n")
 
 var helpTable = cview.NewTextView()
@@ -79,6 +86,10 @@ func helpInit() {
 		strings.Split(config.GetKeyBinding(config.CmdTab9), ",")[0])
 	linkKeys := fmt.Sprintf("%s to %s", strings.Split(config.GetKeyBinding(config.CmdLink1), ",")[0],
 		strings.Split(config.GetKeyBinding(config.CmdLink0), ",")[0])
+	commandKeys := fmt.Sprintf("%s to %s", strings.Split(config.GetKeyBinding(config.CmdCommand1), ",")[0],
+		strings.Split(config.GetKeyBinding(config.CmdCommand0), ",")[0])
+	commandTargetKeys := fmt.Sprintf("%s to %s", strings.Split(config.GetKeyBinding(config.CmdCommandTarget1), ",")[0],
+		strings.Split(config.GetKeyBinding(config.CmdCommandTarget0), ",")[0])
 
 	helpCells = fmt.Sprintf(helpCells,
 		config.GetKeyBinding(config.CmdMoveLeft),
@@ -110,6 +121,11 @@ func helpInit() {
 		config.GetKeyBinding(config.CmdSave),
 		config.GetKeyBinding(config.CmdSub),
 		config.GetKeyBinding(config.CmdAddSub),
+		commandKeys,
+		commandTargetKeys,
+		config.GetKeyBinding(config.CmdSearch),
+		config.GetKeyBinding(config.CmdNextMatch),
+		config.GetKeyBinding(config.CmdPrevMatch),
 		config.GetKeyBinding(config.CmdQuit),
 	)
 
